---
label: IRONCLUST
dockerfile:
environment: MATLAB
wrapper: https://github.com/flatironinstitute/spikeforest/blob/master/spikeforest/spikesorters/ironclust/ironclust.py
website: https://github.com/jamesjun/ironclust
source_code: https://github.com/jamesjun/ironclust
authors: James J. Jun
processor_name: IronClust
doi:
---
_
# IRONCLUST

## Description

Spike sorting software developed at Flatiron Institute, based on JRCLUST (Janelia Rocket Clust).

## Installation notes

**Prerequisites:**

* MATLAB with the following
  - Statistics and Machine Learning Toolbox
  - Parallel Computing Toolbox

## References

